@@ -1,33 +1,30 @@
 package kubernetes
 
 import (
-	_ "embed"
+	"fmt"
+	"strings"
+
 	"github.com/abiosoft/colima/cli"
 	"github.com/abiosoft/colima/environment"
 	"github.com/abiosoft/colima/environment/container/containerd"
 	"github.com/abiosoft/colima/environment/container/docker"
 	"github.com/abiosoft/colima/util/downloader"
-	"runtime"
-	"strings"
+	"github.com/sirupsen/logrus"
 )
 
-const k3sVersion = "v1.22.2+k3s2"
+const k3sVersion = "v1.22.4+k3s1"
 
-func installK3s(host environment.HostActions, guest environment.GuestActions, a *cli.ActiveCommandChain, containerRuntime string) {
+func installK3s(host environment.HostActions, guest environment.GuestActions, a *cli.ActiveCommandChain, log *logrus.Entry, containerRuntime string) {
 	installK3sBinary(host, guest, a)
-	installK3sCache(host, guest, a, containerRuntime)
+	installK3sCache(host, guest, a, log, containerRuntime)
 	installK3sCluster(host, guest, a, containerRuntime)
-
-	if containerRuntime == containerd.Name {
-		installContainerdDeps(guest, a)
-	}
 }
 
 func installK3sBinary(host environment.HostActions, guest environment.GuestActions, a *cli.ActiveCommandChain) {
 	// install k3s last to ensure it is the last step
 	downloadPath := "/tmp/k3s"
 	url := "https://github.com/k3s-io/k3s/releases/download/" + k3sVersion + "/k3s"
-	if runtime.GOARCH == "arm64" {
+	if guest.Arch().GoArch() == "arm64" {
 		url += "-arm64"
 	}
 	a.Add(func() error {
@@ -38,8 +35,8 @@ func installK3sBinary(host environment.HostActions, guest environment.GuestActio
 	})
 }
 
-func installK3sCache(host environment.HostActions, guest environment.GuestActions, a *cli.ActiveCommandChain, containerRuntime string) {
-	imageTar := "k3s-airgap-images-" + runtime.GOARCH + ".tar"
+func installK3sCache(host environment.HostActions, guest environment.GuestActions, a *cli.ActiveCommandChain, log *logrus.Entry, containerRuntime string) {
+	imageTar := "k3s-airgap-images-" + guest.Arch().GoArch() + ".tar"
 	imageTarGz := imageTar + ".gz"
 	downloadPathTar := "/tmp/" + imageTar
 	downloadPathTarGz := "/tmp/" + imageTarGz
@@ -59,16 +56,26 @@ func installK3sCache(host environment.HostActions, guest environment.GuestAction
 		return guest.Run("sudo", "cp", downloadPathTar, airGapDir)
 	})
 
+	// load OCI images for K3s
+	// this can be safely ignored if failed as the images would be pulled afterwards.
 	switch containerRuntime {
 	case containerd.Name:
-		a.Stage("loading containerd images")
+		a.Stage("loading oci images")
 		a.Add(func() error {
-			return guest.Run("sudo", "ctr", "-n", "k8s.io", "images", "import", downloadPathTar)
+			if err := guest.Run("sudo", "ctr", "-n", "k8s.io", "images", "import", downloadPathTar); err != nil {
+				log.Warnln(fmt.Errorf("error loading oci images: %w", err))
+				log.Warnln("startup may delay a bit as images will be pulled from oci registry")
+			}
+			return nil
 		})
 	case docker.Name:
-		a.Stage("loading docker images")
+		a.Stage("loading oci images")
 		a.Add(func() error {
-			return guest.Run("sudo", "docker", "load", "-i", downloadPathTar)
+			if err := guest.Run("sudo", "docker", "load", "-i", downloadPathTar); err != nil {
+				log.Warnln(fmt.Errorf("error loading oci images: %w", err))
+				log.Warnln("startup may delay a bit as images will be pulled from oci registry")
+			}
+			return nil
 		})
 	}
 
@@ -87,7 +94,7 @@ func installK3sCluster(host environment.HostActions, guest environment.GuestActi
 
 	args := []string{
 		"--write-kubeconfig-mode", "644",
-		"--resolv-conf", "/run/systemd/resolve/resolv.conf",
+		"--resolv-conf", "/etc/resolv.conf",
 		"--disable", "traefik",
 	}
 
